@@ -22,7 +22,7 @@ public:
 	static KConfig* config();
 	static QString caption();
 	static void KMsgSorry(QWidget *parent, const char *text);
-	static std::list<string> globalDirs(const char *which);
+	static std::list<std::string> globalDirs(const char *which);
 };
 
 #define KAppNameType QCString
