@@ -60,10 +60,10 @@ KAboutData *KMidFactory::aboutData()
     KAboutData *aboutdata = new KAboutData("kmid", "KMid", "2.0",
         I18N_NOOP("MIDI/Karaoke file player"), KAboutData::License_GPL,
         I18N_NOOP("(C) 1997,98,99,2000, Antonio Larrosa Jimenez"),"",
-        "http://www.arrakis.es/~rlarrosa/kmid.html");
+        "http://perso.wanadoo.es/antlarr/kmid.html");
     aboutdata->addAuthor("Antonio Larrosa Jimenez",
         I18N_NOOP("Original Developer/Mantainer"),"larrosa@kde.org",
-        "http://www.arrakis.es/~rlarrosa/index.html");
+        "http://perso.wanadoo.es/antlarr/index.html");
     return aboutdata;
 }
 
@@ -150,3 +150,4 @@ KMidBrowserExtension::KMidBrowserExtension(KMidPart *parent)
 KMidBrowserExtension::~KMidBrowserExtension()
 {
 }
+#include "kmid_part.moc"
