@@ -3,7 +3,7 @@
  *
  * kscd -- A simple CD player for the KDE project
  *
- * $Id: configdlg.h,v 1.15 2000/02/28 07:11:02 dfoerste Exp $
+ * $Id: configdlg.h,v 1.16 2001/06/12 06:06:45 dfoerste Exp $
  *
  * Copyright (C) 1997 Bernd Johannes Wuebben
  * wuebben@math.cornell.edu
@@ -72,7 +72,6 @@ private slots:
   void ejectOnFinishClicked();
   void device_changed(const QString&);
   void randomOnceClicked();
-  void mail_changed(const QString&);
   void custombutton_clicked();
   void kfmbutton_clicked();
 
@@ -117,9 +116,6 @@ private:
   QLabel *label5;
   QLineEdit *cd_device_edit;
 
-  QLabel *label6;
-  QLineEdit *mail_edit;
-
   QButtonGroup *browserbox;
 
   QRadioButton *kfmbutton;
