@@ -1,5 +1,5 @@
 /*
- * $Id: plat_linux.c,v 1.11 2001/02/04 09:57:33 dfoerste Exp $
+ * $Id: plat_linux.c,v 1.15 2001/06/18 11:01:07 dfoerste Exp $
  *
  * This file is part of WorkMan, the civilized CD player library
  * (c) 1991-1997 by Steven Grimm (original author)
@@ -25,7 +25,7 @@
  * Linux-specific drive control routines.  Very similar to the Sun module.
  */
 
-static char plat_linux_id[] = "$Id: plat_linux.c,v 1.11 2001/02/04 09:57:33 dfoerste Exp $";
+static char plat_linux_id[] = "$Id: plat_linux.c,v 1.15 2001/06/18 11:01:07 dfoerste Exp $";
 
 #if defined(__linux__)
 
@@ -43,6 +43,8 @@ static char plat_linux_id[] = "$Id: plat_linux.c,v 1.11 2001/02/04 09:57:33 dfoe
 #include <sys/wait.h>
 
 #include "include/wm_config.h"
+#include "include/wm_struct.h"
+#include "include/wm_cdtext.h"
 
 #if defined(BSD_MOUNTTEST)
   #include <mntent.h>
@@ -122,6 +124,7 @@ wmcd_open( struct wm_drive *d )
   
   if (cd_device == NULL)
     cd_device = DEFAULT_CD_DEVICE;
+    
   
   if (d->fd >= 0)		/* Device already open? */
     {
@@ -129,9 +132,9 @@ wmcd_open( struct wm_drive *d )
       return (0);
     }
   
-  d->fd = open(cd_device, O_RDONLY | O_NONBLOCK);
+  fd = open(cd_device, O_RDONLY | O_NONBLOCK);
 
-  if (d->fd < 0)
+  if (fd < 0)
     {
       if (errno == EACCES)
 	{
@@ -150,8 +153,6 @@ wmcd_open( struct wm_drive *d )
       retval = 1;
     }
   
-  /* Now fill in the relevant parts of the wm_drive structure. */
-  fd = d->fd;
   
 #ifdef LINUX_SCSI_PASSTHROUGH
   /* Can we figure out the drive type? */
@@ -159,6 +160,7 @@ wmcd_open( struct wm_drive *d )
   if (retval == WM_ERR_SCSI_INQUIRY_FAILED)
     wm_lib_message(WM_MSG_LEVEL_DEBUG|WM_MSG_CLASS, "wmcd_open(): After failed inquiry\n");
 #endif
+
   *d = *(find_drive_struct(vendor, model, rev));
   wm_drive_settype(vendor, model, rev);
   
@@ -204,7 +206,7 @@ wm_scsi( struct wm_drive *d, unsigned char *cdb, int cdblen,
   
   char *cmd;
   int cmdsize;
-  
+
   cmdsize = 2 * sizeof(int);
   if (retbuf)
     {
@@ -241,6 +243,43 @@ wm_scsi( struct wm_drive *d, unsigned char *cdb, int cdblen,
   return 0;
   
 #else /* Linux SCSI passthrough*/
+/*----------------------------------------*
+ * send packet over cdrom interface
+ * kernel >= 2.2.16
+ *----------------------------------------*/
+#ifdef CDROM_SEND_PACKET	
+
+  struct cdrom_generic_command cdc;
+  struct request_sense sense;
+  int ret, capability;
+
+  wm_lib_message(WM_MSG_LEVEL_DEBUG|WM_MSG_CLASS, "wm_scsi over CDROM_SEND_PACKET entered\n");
+
+  capability = ioctl(d->fd, CDROM_GET_CAPABILITY);
+
+  if(!(capability & CDC_GENERIC_PACKET))
+  {
+    wm_lib_message(WM_MSG_LEVEL_DEBUG|WM_MSG_CLASS, "your CDROM or/and kernel don't support CDC_GENERIC_PACKET ...\n");
+    printf("your CDROM or/and kernel don't support CDC_GENERIC_PACKET ...\n");
+    return -1;
+  }
+
+  memset(&cdc, 0, sizeof(struct cdrom_generic_command));
+  memset(&sense, 0, sizeof(struct request_sense));
+	
+  memcpy(cdc.cmd, cdb, cdblen);
+
+  cdc.buffer = retbuf;
+  cdc.buflen = retbuflen;
+  cdc.stat = 0;
+  cdc.sense = &sense;
+  cdc.data_direction = getreply;
+
+  /* sendpacket_over_cdrom_interface() */
+  return ioctl(d->fd, CDROM_SEND_PACKET, &cdc);
+#endif /* CDROM_SEND_PACKET */
+  printf("ERROR: this binary was compiled without CDROM GENERIC PACKET SUPPORT. kernel version < 2.2.16?\n");
+  printf("ERROR: if you have a SCSI CDROM, rebuild it with a #define LINUX_SCSI_PASSTHROUGH\n");
   return (-1);
 #endif
 } /* wm_scsi */
@@ -311,9 +350,15 @@ gen_get_drive_status( struct wm_drive *d, enum wm_cd_modes oldmode,
 	  return (0);
 	}
     }
-  
+ 
+
+  /* Try to get rid of the door locking    */
+  /* Don't care about return value. If it  */
+  /* works - fine. If not - ...            */
+  ioctl( d->fd, CDROM_LOCKDOOR, 0 ); 
+ 
   sc.cdsc_format = CDROM_MSF;
-  
+ 
   if (ioctl(d->fd, CDROMSUBCHNL, &sc))
     return (0);
   
@@ -535,7 +580,9 @@ gen_eject(struct wm_drive *d)
     }
   endmntent (fp);
 #endif /* BSD_MOUNTTEST */
-  
+ 
+  ioctl( d->fd, CDROM_LOCKDOOR, 0 );
+
   if (ioctl(d->fd, CDROMEJECT))
     {
       wm_lib_message(WM_MSG_LEVEL_DEBUG|WM_MSG_CLASS, "eject failed (%s).\n", strerror(errno));
@@ -632,6 +679,22 @@ gen_set_volume( struct wm_drive *d, int left, int right )
   return (ioctl(d->fd, CDROMVOLCTRL, &v));
 } /* gen_set_volume() */
 
+/*------------------------------------------------------------------------*
+ * gen_get_cdtext(drive, buffer, lenght)
+ *
+ * Return a buffer with cdtext-stream. buffer will be allocated and filled
+ *
+ * needs send packet interface -> for IDE, linux at 2.2.16
+ * depends on scsi.c which depends on wm_scsi defined in here
+ * (which also takes care of IDE drives)
+ *------------------------------------------------------------------------*/
+
+int
+gen_get_cdtext(struct wm_drive *d, unsigned char **pp_buffer, int *p_buffer_lenght)
+{
+  return wm_scsi_get_cdtext(d, pp_buffer, p_buffer_lenght);
+} /* gen_get_cdtext() */
+
 /*---------------------------------------------------------------------*
  * Read the initial volume from the drive, if available.  Each channel
  * ranges from 0 to 100, with -1 indicating data not available.
