@@ -1,5 +1,5 @@
 /*
- * $Id: plat_openbsd.c,v 1.6 2001/01/30 05:56:20 dfoerste Exp $
+ * $Id: plat_openbsd.c,v 1.7 2001/04/10 17:34:52 dfoerste Exp $
  *
  * This file is part of WorkMan, the civilized CD player library
  * (c) 1991-1997 by Steven Grimm (original author)
@@ -29,7 +29,7 @@
  *
  */
 
-static char plat_openbsd[] = "$Id: plat_openbsd.c,v 1.6 2001/01/30 05:56:20 dfoerste Exp $";
+static char plat_openbsd[] = "$Id: plat_openbsd.c,v 1.7 2001/04/10 17:34:52 dfoerste Exp $";
 
 #if defined(__OpenBSD__) || defined(__OpenBSD)
 
@@ -59,6 +59,7 @@ static char plat_openbsd[] = "$Id: plat_openbsd.c,v 1.6 2001/01/30 05:56:20 dfoe
 #include <scsi/scsi_cd.h>
 
 #include "include/wm_struct.h"
+#include "include/wm_cdtext.h"
 
 #define WM_MSG_CLASS WM_MSG_CLASS_PLATFORM
 
@@ -519,4 +520,14 @@ gen_get_volume(struct wm_drive *d, int *left, int *right)
   return (0);
 } /* gen_get_volume() */
 
+/*------------------------------------------------------------------------*
+ * gen_get_cdtext(drive, buffer, lenght)
+ *------------------------------------------------------------------------*/
+
+int
+gen_get_cdtext(struct wm_drive *d, unsigned char **pp_buffer, int *p_buffer_lenght)
+{
+  return -1; /* no SCSI, no CDTEXT */
+} /* gen_get_cdtext() */
+
 #endif
