@@ -14,6 +14,7 @@
 #ifndef __X11SURFACE_H
 #define __X11SURFACE_H
 
+#include <values.h>
 #include "xinit.h"
 #include "../surface.h"
 #include "initDisplay.h"
@@ -27,18 +28,17 @@
 class X11Surface : public Surface {
 
   int lOpen;
-  int imageSize;
   int imageMode;
   
   XWindow* xWindow;
 
-  ImageBase* imageCurrent;
+  ImageBase** imageList;
+  int         images;
   
-  ImageDeskX11* imageDeskX11Out;
-  ImageDGAFull* imageFullDGA;
-  ImageXVDesk* imageDeskXV;
+  ImageBase* imageCurrent;
 
   Atom WM_DELETE_WINDOW;
+  Atom WM_RESIZE_WINDOW;
   int lXVAllow;
 
  public:
@@ -46,18 +46,26 @@ class X11Surface : public Surface {
   ~X11Surface();
 
   int isOpen();
-  int open(int width, int height,const char *title);
+  int open(int width, int height,const char *title, bool border = false);
   int close();
   int getHeight();
   int getWidth();
   int getDepth();
+  int getImageMode();
+  
+  ImageBase *findImage(int mode);
+	  
+  // these functions grant access to the supported images. be careful when changing
+  // entries, because these are no copies. they are the original values!
+  ImageBase **getModes();
+  void setModes(ImageBase **modes);
 
-  int openImage(int imageSize,int imageMode);
+  int openImage(int mode, YUVPicture* pic = NULL);
   int closeImage();
   int dither(YUVPicture* pic);
   int putImage(YUVPicture* pic);
 
-  int checkEvent(int* mode,int* size);
+  int checkEvent(int* mode);
   
   void config(const char* key, 
 	      const char* value,void* user_data);
